pub unsafe extern "C" fn splinter_client_set_tandem(
base_key: *const c_char,
vals: *mut *const c_void,
lens: *const usize,
orders: u8,
) -> c_intExpand description
@brief Client-side helper to write multiple orders of a key. This helper manages the naming convention for the caller. It uses a temporary array to copy the “victim” keys. @param base_key The main key (e.g. car) @param vals An array of values from keys that will be merged in @param lens An array of lengths corresponding with vals @param orders How many tandems to create @return 0 on success, -1 on failure, -2 if underlying basic I/O calls fail