splinter_create_or_open

Function splinter_create_or_open 

pub unsafe extern "C" fn splinter_create_or_open(
    name_or_path: *const c_char,
    slots: usize,
    max_value_sz: usize,
) -> c_int
@brief Creates a new splinter store, or opens it if it already exists. @param name_or_path The name of the shared memory object or path to the file. @param slots The total number of key-value slots if creating. @param max_value_sz The maximum value size in bytes if creating. @return 0 on success, -1 on failure.