splinter_set_slot_time

Function splinter_set_slot_time 

pub unsafe extern "C" fn splinter_set_slot_time(
    key: *const c_char,
    mode: c_ushort,
    epoch: u64,
    offset: usize,
) -> c_int
@brief Update a slot’s ctime / atime @param key Name of the key to change @param mode (SPL_TIME_CTIME or SPL_TIME_ATIME) @param epoch client-supplied timestamp @param offset value to subtract from epoch due to update-after-write @return -1/-2 or on error (sets errno), 0 on success