pub unsafe extern "C" fn splinter_integer_op(
key: *const c_char,
op: splinter_integer_op_t,
mask: *const c_void,
) -> c_intExpand description
@brief Bitwise & arithmetic ops on keys named as big unsigned @param key Name of the key to operate on @param op Operation you want to do @param mask What you want to do it with @return 0 on success, -1 / -2 on internal / caller errors respectively