pub unsafe extern "C" fn splinter_unset(key: *const c_char) -> c_intExpand description
@brief “unsets” a key. This function does one atomic operation to zero the slot hash, which marks the slot available for write. It then zeroes out the used key and value regions, and resets the slot.
@param key The null-terminated key string. @return length of value deleted, -1 if key not found, - 2 if null key/store